Class: BatchlyApi::AccountsController

Inherits:
Object
  • Object
show all
Defined in:
lib/batchly_api/controllers/accounts_controller.rb

Instance Method Summary collapse

Instance Method Details

#add_aws_cloud_account(model) ⇒ Object

Adds a new AWS account to batchly. AWS Accesskey and Secretkey should have ‘IAMFullAccess’ Permissions.

Shared AWS keys are not stored in our servers. Keys are used to create a new role and then discarded.

Parameters:

  • model (AddAWSAccountRequest)

    Required parameter: Request model for adding AWS account

Returns:

  • AccountModel response from the API call



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/batchly_api/controllers/accounts_controller.rb', line 48

def  model
  # the base uri for api requests

  query_builder = Configuration.BASE_URI.dup

  # prepare query string for API call

  query_builder << "/api/Accounts/AWS"

  # validate and preprocess url

  query_url = APIHelper.clean_url query_builder

  # prepare headers

  headers = {
    "user-agent" => "batchly/1.0.1",
    "accept" => "application/json",
    "content-type" => "application/json; charset=utf-8"
  }

  # append custom auth authorization

  CustomAuthUtility.append_custom_auth_params query_url, "POST", headers

  # invoke the API call request to fetch the response

  response = Unirest.post query_url, headers:headers, parameters:model.to_json

  # Error handling using HTTP status codes

  if response.code == 400
    raise APIException.new "BadRequest", 400, response.raw_body
  elsif !(response.code.between?(200,206)) # [200,206] = HTTP OK

    raise APIException.new "HTTP Response Not OK", response.code, response.raw_body
  end

  response.body
end

#delete(id) ⇒ Object

Deletes the specified account. All projects, jobs, processors associated with the account are made inactive.

Parameters:

  • id (String)

    Required parameter: Account Identifier.

Returns:

  • void response from the API call



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
# File 'lib/batchly_api/controllers/accounts_controller.rb', line 116

def delete id
  # the base uri for api requests

  query_builder = Configuration.BASE_URI.dup

  # prepare query string for API call

  query_builder << "/api/Accounts/{id}"

  # process optional query parameters

  query_builder = APIHelper.append_url_with_template_parameters query_builder, {
    "id" => id,
  }

  # validate and preprocess url

  query_url = APIHelper.clean_url query_builder

  # prepare headers

  headers = {
    "user-agent" => "batchly/1.0.1"
  }

  # append custom auth authorization

  CustomAuthUtility.append_custom_auth_params query_url, "DELETE", headers

  # invoke the API call request to fetch the response

  response = Unirest.delete query_url, headers:headers

  # Error handling using HTTP status codes

  if response.code == 404
    raise APIException.new "NotFound", 404, response.raw_body
  elsif !(response.code.between?(200,206)) # [200,206] = HTTP OK

    raise APIException.new "HTTP Response Not OK", response.code, response.raw_body
  end
end

#list_accountsObject

Returns a Lists of all the active accounts in batchly.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/batchly_api/controllers/accounts_controller.rb', line 83

def list_accounts
  # the base uri for api requests

  query_builder = Configuration.BASE_URI.dup

  # prepare query string for API call

  query_builder << "/api/Accounts"

  # validate and preprocess url

  query_url = APIHelper.clean_url query_builder

  # prepare headers

  headers = {
    "user-agent" => "batchly/1.0.1",
    "accept" => "application/json"
  }

  # append custom auth authorization

  CustomAuthUtility.append_custom_auth_params query_url, "GET", headers

  # invoke the API call request to fetch the response

  response = Unirest.get query_url, headers:headers

  #Error handling using HTTP status codes

  if !(response.code.between?(200,206)) # [200,206] = HTTP OK

    raise APIException.new "HTTP Response Not OK", response.code, response.raw_body
  end

  response.body
end

#list_projects(id) ⇒ Object

Returns a Lists of all the projects for the given account identifier.

Parameters:

  • id (String)

    Required parameter: Account ID



9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
# File 'lib/batchly_api/controllers/accounts_controller.rb', line 9

def list_projects id
  # the base uri for api requests

  query_builder = Configuration.BASE_URI.dup

  # prepare query string for API call

  query_builder << "/api/Accounts/{id}/Projects"

  # process optional query parameters

  query_builder = APIHelper.append_url_with_template_parameters query_builder, {
    "id" => id,
  }

  # validate and preprocess url

  query_url = APIHelper.clean_url query_builder

  # prepare headers

  headers = {
    "user-agent" => "batchly/1.0.1",
    "accept" => "application/json"
  }

  # append custom auth authorization

  CustomAuthUtility.append_custom_auth_params query_url, "GET", headers

  # invoke the API call request to fetch the response

  response = Unirest.get query_url, headers:headers

  #Error handling using HTTP status codes

  if !(response.code.between?(200,206)) # [200,206] = HTTP OK

    raise APIException.new "HTTP Response Not OK", response.code, response.raw_body
  end

  response.body
end