Class: BatchlyApi::ProcessorsController
- Inherits:
-
Object
- Object
- BatchlyApi::ProcessorsController
- Defined in:
- lib/batchly_api/controllers/processors_controller.rb
Instance Method Summary collapse
-
#add_parameter_group(processor_id, request) ⇒ Object
Parameter groups are a package of different runtime parameters that are addressed as a single entity.
-
#add_processor_to_job(request) ⇒ Object
Allows creation of a new Processor that will be used for the job.
-
#add_processor_to_vault(request) ⇒ Object
Allows creation of a new Processor in your secure vault.
-
#describe_parameter_group(parameter_group_id, processor_id) ⇒ Object
Describes in detail the runtime parameters associated with the parameter group.
-
#list_marketplace_processors ⇒ Object
batch.ly is a marketplace for third party vendors to showcase their processors.
-
#list_vault_processors(account_id) ⇒ Object
batch.ly vault is secure storage of processors that belong only to you.
-
#upload_file(accountid, file) ⇒ Object
Upload your processor code as a zip file to the endpoint.
Instance Method Details
#add_parameter_group(processor_id, request) ⇒ Object
Parameter groups are a package of different runtime parameters that are addressed as a single entity. Different configuration of processors can be done using parameter groups and during each job execution you can choose to use the right runtime parameters.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/batchly_api/controllers/processors_controller.rb', line 80 def add_parameter_group processor_id, request # the base uri for api requests query_builder = Configuration.BASE_URI.dup # prepare query string for API call query_builder << "/api/Processors/{processorId}/ParameterGroups" # process optional query parameters query_builder = APIHelper.append_url_with_template_parameters query_builder, { "processorId" => processor_id, } # validate and preprocess url query_url = APIHelper.clean_url query_builder # prepare headers headers = { "user-agent" => "batchly/0.6.8", "accept" => "application/json", "content-type" => "application/json; charset=utf-8" } # append custom auth authorization CustomAuthUtility.append_custom_auth_params query_url, "POST", headers # invoke the API call request to fetch the response response = Unirest.post query_url, headers:headers, parameters:request.to_json #Error handling using HTTP status codes if !(response.code.between?(200,206)) # [200,206] = HTTP OK raise APIException.new "HTTP Response Not OK", response.code, response.raw_body end response.body end |
#add_processor_to_job(request) ⇒ Object
Allows creation of a new Processor that will be used for the job
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/batchly_api/controllers/processors_controller.rb', line 236 def add_processor_to_job request # the base uri for api requests query_builder = Configuration.BASE_URI.dup # prepare query string for API call query_builder << "/api/Processors" # validate and preprocess url query_url = APIHelper.clean_url query_builder # prepare headers headers = { "user-agent" => "batchly/0.6.8", "accept" => "application/json", "content-type" => "application/json; charset=utf-8" } # append custom auth authorization CustomAuthUtility.append_custom_auth_params query_url, "POST", headers # invoke the API call request to fetch the response response = Unirest.post query_url, headers:headers, parameters:request.to_json #Error handling using HTTP status codes if !(response.code.between?(200,206)) # [200,206] = HTTP OK raise APIException.new "HTTP Response Not OK", response.code, response.raw_body end response.body end |
#add_processor_to_vault(request) ⇒ Object
Allows creation of a new Processor in your secure vault
159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/batchly_api/controllers/processors_controller.rb', line 159 def add_processor_to_vault request # the base uri for api requests query_builder = Configuration.BASE_URI.dup # prepare query string for API call query_builder << "/api/Processors/Vault" # validate and preprocess url query_url = APIHelper.clean_url query_builder # prepare headers headers = { "user-agent" => "batchly/0.6.8", "accept" => "application/json", "content-type" => "application/json; charset=utf-8" } # append custom auth authorization CustomAuthUtility.append_custom_auth_params query_url, "POST", headers # invoke the API call request to fetch the response response = Unirest.post query_url, headers:headers, parameters:request.to_json #Error handling using HTTP status codes if !(response.code.between?(200,206)) # [200,206] = HTTP OK raise APIException.new "HTTP Response Not OK", response.code, response.raw_body end response.body end |
#describe_parameter_group(parameter_group_id, processor_id) ⇒ Object
Describes in detail the runtime parameters associated with the parameter group
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/batchly_api/controllers/processors_controller.rb', line 120 def describe_parameter_group parameter_group_id, processor_id # the base uri for api requests query_builder = Configuration.BASE_URI.dup # prepare query string for API call query_builder << "/api/Processors/{processorId}/ParameterGroups/{parameterGroupId}" # process optional query parameters query_builder = APIHelper.append_url_with_template_parameters query_builder, { "parameterGroupId" => parameter_group_id, "processorId" => processor_id, } # validate and preprocess url query_url = APIHelper.clean_url query_builder # prepare headers headers = { "user-agent" => "batchly/0.6.8", "accept" => "application/json" } # append custom auth authorization CustomAuthUtility.append_custom_auth_params query_url, "GET", headers # invoke the API call request to fetch the response response = Unirest.get query_url, headers:headers #Error handling using HTTP status codes if !(response.code.between?(200,206)) # [200,206] = HTTP OK raise APIException.new "HTTP Response Not OK", response.code, response.raw_body end response.body end |
#list_marketplace_processors ⇒ Object
batch.ly is a marketplace for third party vendors to showcase their processors. These processors are available for use to anyone.
8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 |
# File 'lib/batchly_api/controllers/processors_controller.rb', line 8 def list_marketplace_processors # the base uri for api requests query_builder = Configuration.BASE_URI.dup # prepare query string for API call query_builder << "/api/Processors/Marketplace" # validate and preprocess url query_url = APIHelper.clean_url query_builder # prepare headers headers = { "user-agent" => "batchly/0.6.8", "accept" => "application/json" } # append custom auth authorization CustomAuthUtility.append_custom_auth_params query_url, "GET", headers # invoke the API call request to fetch the response response = Unirest.get query_url, headers:headers #Error handling using HTTP status codes if !(response.code.between?(200,206)) # [200,206] = HTTP OK raise APIException.new "HTTP Response Not OK", response.code, response.raw_body end response.body end |
#list_vault_processors(account_id) ⇒ Object
batch.ly vault is secure storage of processors that belong only to you. Processors added to vault are available only for your use. They can be used in all projects that are under the account in which the processor was originally added. Cross account usage of processors are currently not supported.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/batchly_api/controllers/processors_controller.rb', line 41 def list_vault_processors account_id # the base uri for api requests query_builder = Configuration.BASE_URI.dup # prepare query string for API call query_builder << "/api/Processors/Vault/{accountId}" # process optional query parameters query_builder = APIHelper.append_url_with_template_parameters query_builder, { "accountId" => account_id, } # validate and preprocess url query_url = APIHelper.clean_url query_builder # prepare headers headers = { "user-agent" => "batchly/0.6.8", "accept" => "application/json" } # append custom auth authorization CustomAuthUtility.append_custom_auth_params query_url, "GET", headers # invoke the API call request to fetch the response response = Unirest.get query_url, headers:headers #Error handling using HTTP status codes if !(response.code.between?(200,206)) # [200,206] = HTTP OK raise APIException.new "HTTP Response Not OK", response.code, response.raw_body end response.body end |
#upload_file(accountid, file) ⇒ Object
Upload your processor code as a zip file to the endpoint. Multipart formdata file content
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/batchly_api/controllers/processors_controller.rb', line 194 def upload_file accountid, file # the base uri for api requests query_builder = Configuration.BASE_URI.dup # prepare query string for API call query_builder << "/api/Processors/Upload" # process optional query parameters query_builder = APIHelper.append_url_with_query_parameters query_builder, { "accountid" => accountid, } # validate and preprocess url query_url = APIHelper.clean_url query_builder # prepare headers headers = { "user-agent" => "batchly/0.6.8" } # append custom auth authorization CustomAuthUtility.append_custom_auth_params query_url, "POST", headers # prepare parameters parameters = { "file" => file } # invoke the API call request to fetch the response response = Unirest.post query_url, headers:headers, parameters:parameters #Error handling using HTTP status codes if !(response.code.between?(200,206)) # [200,206] = HTTP OK raise APIException.new "HTTP Response Not OK", response.code, response.raw_body end response.body end |